@@ -10,52 +10,56 @@
 import thermosteam as tmo
 from flexsolve import IQ_interpolation
 from .utils import copy_maybe
-from .properties.identifiers import chemical_metadata_from_any, pubchem_db
-from .properties.vapor_pressure import vapor_pressure_handle
-from .properties.phase_change import (normal_boiling_point_temperature,
-                                      normal_melting_point_temperature,
-                                      heat_of_fusion,
-                                      heat_of_vaporization_handle)
-from .properties.critical import (Ihmels,
-                                  critical_point_temperature,
-                                  critical_point_pressure,
-                                  critical_point_volume)
-from .properties.acentric import (acentric_factor,
-                                  compute_acentric_factor,
-                                  estimate_acentric_factor_LK,
-                                  compute_Stiel_Polar)
-from .properties.triple import triple_point_temperature, triple_point_pressure
-from .properties.volume import volume_handle
-from .properties.heat_capacity import heat_capacity_handle
-from .properties.reaction import heat_of_formation
-from .properties.combustion import CombustionData
-from .properties.elements import (compute_similarity_variable, 
-                                  parse_simple_formula as get_atoms,
-                                  compute_molecular_weight)
-from .properties.eos import GCEOS_DUMMY, PR
-from .properties.viscosity import viscosity_handle
-from .properties.thermal_conductivity import thermal_conductivity_handle
-from .properties.free_energy import (
+from chemicals.identifiers import pubchem_db
+from chemicals.vapor_pressure import vapor_pressure_handle
+from chemicals.phase_change import (Tb as normal_boiling_point_temperature,
+                                    Tm as normal_melting_point_temperature,
+                                    Hfus as heat_of_fusion,
+                                    heat_of_vaporization_handle)
+from chemicals.critical import (Ihmels,
+                                Tc as critical_point_temperature,
+                                Pc as critical_point_pressure,
+                                Vc as critical_point_volume)
+from chemicals.acentric import (omega as acentric_factor,
+                                omega_definition as acentric_factor_definition,
+                                LK_omega as acentric_factor_LK,
+                                Stiel_polar_factor as compute_Stiel_Polar)
+from chemicals.triple import (Tt as triple_point_temperature,
+                              Pt as triple_point_pressure)
+from chemicals.combustion import combustion_data, combustion_stoichiometry
+from chemicals.volume import volume_handle
+from chemicals.heat_capacity import heat_capacity_handle
+from chemicals.reaction import Hf as heat_of_formation
+from chemicals.elements import (similarity_variable as compute_similarity_variable, 
+                                simple_formula_parser as get_atoms,
+                                molecular_weight as compute_molecular_weight)
+from chemicals.viscosity import viscosity_handle
+from chemicals.thermal_conductivity import thermal_conductivity_handle
+from chemicals.permittivity import permitivity_handle
+from chemicals.interface import surface_tension_handle
+from chemicals.dipole import dipole_moment
+from .free_energy import (
     Enthalpy, Entropy,
     EnthalpyRefSolid, EnthalpyRefLiquid, EnthalpyRefGas,
     EntropyRefSolid, EntropyRefLiquid, EntropyRefGas,
     ExcessEnthalpyRefSolid, ExcessEnthalpyRefLiquid, ExcessEnthalpyRefGas,
-    ExcessEntropyRefSolid, ExcessEntropyRefLiquid, ExcessEntropyRefGas)
+    ExcessEntropyRefSolid, ExcessEntropyRefLiquid, ExcessEntropyRefGas
+)
+from .eos import GCEOS_DUMMY, PR
+from .equilibrium.unifac import (
+    DDBST_UNIFAC_assignments, 
+    DDBST_MODIFIED_UNIFAC_assignments,
+    DDBST_PSRK_assignments,
+    UNIFACGroupCounts, 
+    DortmundGroupCounts, 
+    PSRKGroupCounts
+)
 from .base import (PhaseHandle, PhaseTHandle, PhaseTPHandle,
                    ThermoModelHandle, TDependentModelHandle,
                    TPDependentModelHandle, display_asfunctor)
 from .units_of_measure import chemical_units_of_measure
-from .properties.dipole import dipole_moment
 from . import functional as fn 
-from .properties.permittivity import permitivity_handle
-from .properties.interface import surface_tension_handle
-from .properties.unifac import (DDBST_UNIFAC_assignments, 
-                                DDBST_MODIFIED_UNIFAC_assignments,
-                                DDBST_PSRK_assignments,
-                                UNIFACGroupCounts, 
-                                DortmundGroupCounts, 
-                                PSRKGroupCounts)
-from .exceptions import DomainError
+
 # from .solubility import SolubilityParameter
 # from .lennard_jones import Stockmayer, MolecularDiameter
 # from .environment import GWP, ODP, logP
@@ -276,7 +280,7 @@ class Chemical:
              Pt: 610.88 Pa
              Pc: 2.2048e+07 Pa
              Vc: 5.6e-05 m^3/mol
-             Hf: -2.8569e+05 J/mol
+             Hf: -2.8582e+05 J/mol
              LHV: 44011 J/mol
              HHV: 0 J/mol
              Hfus: 6010 J/mol
@@ -284,7 +288,7 @@ class Chemical:
              dipole: 1.85 Debye
              similarity_variable: 0.16653
              iscyclic_aliphatic: 0
-             combustion: {}
+             combustion: {'H2O': 1.0}
 
     All fields shown are accessible:
     
@@ -300,13 +304,13 @@ class Chemical:
         
     >>> # Vapor pressure (Pa)
     >>> Water.Psat(T=373.15)
-    101284.55179999319
+    101284.55...
     >>> # Surface tension (N/m)
     >>> Water.sigma(T=298.15)
-    0.07205503890847455
+    0.07197220523...
     >>> # Molar volume (m^3/mol)
     >>> Water.V(phase='l', T=298.15, P=101325)
-    1.806920448788909e-05
+    1.80692...e-05
     
     Note that the reference state of all chemicals is 25 degC and 1 atm:
     
@@ -329,11 +333,11 @@ class Chemical:
     
     >>> Water.Psat.show()
     TDependentModelHandle(T, P=None) -> Psat [Pa]
-    [0] Wagner McGraw
+    [0] Wagner original
     [1] Antoine
-    [2] DIPPR EQ101
+    [2] EQ101
     [3] Wagner
-    [4] Boiling Critical Relation
+    [4] boiling critical relation
     [5] Lee Kesler
     [6] Ambrose Walton
     [7] Sanjari
@@ -350,7 +354,7 @@ class Chemical:
     
     >>> Water.Psat[0].show()
     TDependentModel(T, P=None) -> Psat [Pa]
-     name: Wagner McGraw
+     name: Wagner original
      Tmin: 275 K
      Tmax: 647.35 K
 
@@ -376,7 +380,7 @@ class Chemical:
         
     >>> functor = Water.Psat[0].evaluate
     >>> functor.show()
-    Functor: Wagner_McGraw(T, P=None) -> Psat [Pa]
+    Functor: Wagner_original(T, P=None) -> Psat [Pa]
      Tc: 647.35 K
      Pc: 2.2122e+07 Pa
      a: -7.7645
@@ -396,11 +400,11 @@ class Chemical:
     >>> Water.Psat.show()
     TDependentModelHandle(T, P=None) -> Psat [Pa]
     [0] User antoine model
-    [1] Wagner McGraw
+    [1] Wagner original
     [2] Antoine
-    [3] DIPPR EQ101
+    [3] EQ101
     [4] Wagner
-    [5] Boiling Critical Relation
+    [5] boiling critical relation
     [6] Lee Kesler
     [7] Ambrose Walton
     [8] Sanjari
@@ -427,14 +431,14 @@ class Chemical:
     
     >>> # Note: In this case, we pass the model name, but its
     >>> # also possible to pass the current index, or the model itself.
-    >>> Water.Psat.move_up_model_priority('Wagner McGraw')
+    >>> Water.Psat.move_up_model_priority('Wagner original')
     >>> Water.Psat.show()
     TDependentModelHandle(T, P=None) -> Psat [Pa]
-    [0] Wagner McGraw
+    [0] Wagner original
     [1] Antoine
-    [2] DIPPR EQ101
+    [2] EQ101
     [3] Wagner
-    [4] Boiling Critical Relation
+    [4] boiling critical relation
     [5] Lee Kesler
     [6] Ambrose Walton
     [7] Sanjari
@@ -445,10 +449,10 @@ class Chemical:
     >>> Water.Psat.show()
     TDependentModelHandle(T, P=None) -> Psat [Pa]
     [0] Antoine
-    [1] Wagner McGraw
-    [2] DIPPR EQ101
+    [1] Wagner original
+    [2] EQ101
     [3] Wagner
-    [4] Boiling Critical Relation
+    [4] boiling critical relation
     [5] Lee Kesler
     [6] Ambrose Walton
     [7] Sanjari
@@ -460,11 +464,11 @@ class Chemical:
     >>> Water.Psat.set_model_priority('Antoine', 1)
     >>> Water.Psat.show()
     TDependentModelHandle(T, P=None) -> Psat [Pa]
-    [0] Wagner McGraw
+    [0] Wagner original
     [1] Antoine
-    [2] DIPPR EQ101
+    [2] EQ101
     [3] Wagner
-    [4] Boiling Critical Relation
+    [4] boiling critical relation
     [5] Lee Kesler
     [6] Ambrose Walton
     [7] Sanjari
@@ -530,7 +534,7 @@ class Chemical:
             phase = phase[0].lower()
             assert phase in ('s', 'l', 'g'), "phase must be either 's', 'l', or 'g'"
         if search_db:
-            metadata = chemical_metadata_from_any(search_ID)
+            metadata = pubchem_db.search(search_ID)
             data['metadata'] = metadata
             self = cls.new(ID, metadata.CASs, eos, phase_ref, phase,
                            **data)
@@ -1058,7 +1062,7 @@ class Chemical:
         if all([Psat, omega, Tc, Pc]):
             P_at_Tr_sixtenths = Psat.try_out(0.6 * Tc)
             if P_at_Tr_sixtenths:
-                Stiel_Polar = compute_Stiel_Polar(P_at_Tr_sixtenths, omega, Pc)
+                Stiel_Polar = compute_Stiel_Polar(P_at_Tr_sixtenths, Pc, omega)
             else:
                 Stiel_Polar = None
         else:
@@ -1091,8 +1095,9 @@ class Chemical:
         If no combustion stoichiometry is available, return None."""
         combustion = self._combustion
         if not combustion: return None
-        combustion = combustion.copy()
+        if len(combustion) == 1: return None
         ID = self._ID
+        combustion = combustion.copy()
         combustion[ID] = -1
         return tmo.reaction.Reaction(combustion, ID, 1.0, chemicals)
     
@@ -1207,12 +1212,11 @@ class Chemical:
     def reset_combustion_data(self, method="Stoichiometry"):
         """Reset combustion data (LHV, HHV, and combution attributes)
         based on the molecular formula and the heat of formation."""
-        CD = CombustionData.from_chemical_data(self.atoms, self._CAS,
-                                               self._MW, self._Hf, method)
-        if not self._MW: self._MW = CD.MW
-        self._LHV = CD.LHV
-        self._HHV = CD.HHV
-        self._combustion = CD.stoichiometry
+        cd = combustion_data(self.atoms, Hf=self._Hf, MW=self._MW, method=method)
+        if not self._MW: self._MW = cd.MW
+        self._LHV = cd.LHV
+        self._HHV = cd.HHV
+        self._combustion = cd.stoichiometry
     
     def reset_free_energies(self):
         """Reset the `H`, `S`, `H_excess`, and `S_excess` functors."""
@@ -1259,7 +1263,8 @@ class Chemical:
         self._Tc = Tc = Tc or critical_point_temperature(CAS)
         self._Pc = Pc = Pc or critical_point_pressure(CAS)
         self._Vc = Vc or critical_point_volume(CAS)
-        self._omega = omega or acentric_factor(CAS, Tb, Tc, Pc)
+        data = (Tb, Tc, Pc)
+        self._omega = omega or acentric_factor(CAS) or (acentric_factor_LK(*data) if all(data) else None)
 
         # Triple point
         self._Pt = Pt or triple_point_pressure(CAS)
@@ -1284,11 +1289,10 @@ class Chemical:
         self._Hf = Hf
         atoms = atoms or self.atoms
         if not all([LHV, HHV, combustion]) and atoms and Hf:
-            CD = CombustionData.from_chemical_data(
-                 atoms, self._CAS, self._MW, self._Hf)
-            LHV = CD.LHV
-            HHV = CD.HHV
-            combustion = CD.stoichiometry
+            cd = combustion_data(atoms, Hf=self._Hf, MW=self._MW, missing_handling='Ash')
+            LHV = cd.LHV
+            HHV = cd.HHV
+            combustion = cd.stoichiometry
         self._LHV = LHV
         self._HHV = HHV
         self._combustion = combustion
@@ -1327,7 +1331,7 @@ class Chemical:
         self._mu = mu = viscosity_handle(None, ldata, gdata)
         
         # Conductivity
-        ldata = (CAS, MW, Tm, Tb, Tc, Pc, omega)
+        ldata = (CAS, MW, Tm, Tb, Tc, Pc, omega, V.l)
         gdata = (CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, dipole, V.g, Cn.g, mu.g)
         self._kappa = thermal_conductivity_handle(None, ldata, gdata)
         
@@ -1374,9 +1378,9 @@ class Chemical:
         if not omega and Pc and Tc:
             P_at_Tr_seventenths = self._Psat.try_out(0.7 * Tc)
             if P_at_Tr_seventenths:
-                omega = compute_acentric_factor(P_at_Tr_seventenths, Pc)
+                omega = acentric_factor_definition(P_at_Tr_seventenths, Pc)
             if not omega and Tb:
-                omega = estimate_acentric_factor_LK(Tb, Tc, Pc)
+                omega = acentric_factor_LK(Tb, Tc, Pc)
             self._omega = omega
 
     def _init_energies(self, Cn, Hvap, Psat, Hfus, Tm, Tb, eos, eos_1atm,
@@ -1397,8 +1401,8 @@ class Chemical:
             has_Cng = bool(Cn_g)
         elif Cn and single_phase:
             self._phase_ref = single_phase
-            self._H = Enthalpy(Cn, T_ref, H_ref)
-            self._S = Entropy(Cn, T_ref, S_ref)
+            self._H = Enthalpy.functor(Cn, T_ref, H_ref)
+            self._S = Entropy.functor(Cn, T_ref, S_ref)
             Cn_s = Cn_l = Cn_g = Cn
             has_Cns = has_Cnl = has_Cng = True
         else:
@@ -1604,16 +1608,27 @@ class Chemical:
                     method = 'Dulong'
                 else:
                     method = 'Stoichiometry'
-                CD = CombustionData.from_chemical_data(self.atoms, self._CAS,
-                                                       MW, self._Hf, method)
-                if 'Hf' in properties:
-                    self._Hf = CD.Hf
-                if 'HHV' in properties:
-                    self._HHV = CD.HHV
-                if 'LHV' in properties:
-                    self._LHV = CD.LHV
-                if 'combustion' in properties:
-                    self._combustion = CD.stoichiometry
+                stoichiometry = combustion_stoichiometry(self.atoms, MW=MW, missing_handling='Ash')
+                try:
+                    cd = combustion_data(self.atoms, Hf=self._Hf, MW=MW, stoichiometry=stoichiometry, method=method)
+                except:
+                    if 'Hf' in properties:
+                        self._Hf = 0.
+                    if 'HHV' in properties:
+                        self._HHV = 0.
+                    if 'LHV' in properties:
+                        self._LHV = 0.
+                    if 'combustion' in properties:
+                        self._combustion = stoichiometry
+                else:
+                    if 'Hf' in properties:
+                        self._Hf = cd.Hf
+                    if 'HHV' in properties:
+                        self._HHV = cd.HHV
+                    if 'LHV' in properties:
+                        self._LHV = cd.LHV
+                    if 'combustion' in properties:
+                        self._combustion = stoichiometry
         else:
             if 'LHV' in properties:
                 self._LHV = 0
@@ -1783,6 +1798,10 @@ def lock_phase(chemical, phase):
         if hasfield(phase_property, phase):
             functor = getfield(phase_property, phase)
             setfield(chemical, field, functor)
+    Cn = chemical.Cn
+    chemical._phase_ref = phase
+    chemical._H = Enthalpy.functor(Cn, chemical.T_ref, chemical.H_ref)
+    chemical._S = Entropy.functor(Cn, chemical.T_ref, chemical.S_ref)
     chemical._locked_state = phase
 
 # # Fire Safety Limits
