@@ -129,13 +129,15 @@ class ThermoModelHandle:
         self._models = deque(models) if models else deque()
     
     def __getitem__(self, index):
-        return self._models[index]
+        models = self._models
+        return models[as_model_index(models, index)]
     
     def __setitem__(self, index, model):
         assert isinstance(model, ThermoModel), (
             "a 'ThermoModelHandle' object may only "
             "contain 'ThermoModel' objects")
-        self._models[index] = model
+        models = self._models
+        models[as_model_index(models, index)] = model
 	
     def __iter__(self):
         return iter(self._models)
@@ -313,7 +315,7 @@ class TDependentModelHandle(ThermoModelHandle):
                 elif Ta < Tmax:
                     integral += model.integrate_by_T(Ta, Tmax)
                     Ta = Tmax
-            elif ub_satisfied and Tmin < Tb:
+            elif ub_satisfied and Tb > Tmin:
                 integral += model.integrate_by_T(Tmin, Tb)
                 Tb = Tmin
         raise DomainError(f"{no_valid_model(self._chemical, self._var)} "
