@@ -12,7 +12,7 @@ This module includes classes and functions relating string coloring and format.
 from colorpalette import Color, Palette
 import numpy as np
 
-__all__ = ('colors',)
+__all__ = ('colors', 'CABBI_palette')
 
 # %% Classes for coloring
 
@@ -64,9 +64,11 @@ colors.brown_shade = colors.brown.shade(25)
 colors.grey = Color('grey', 255*np.array([0.565, 0.569, 0.557]))
 colors.grey_tint = colors.grey.tint(25)
 colors.grey_shade = colors.grey.shade(25)
+colors.grey_dark = colors.grey.shade(50)
 colors.neutral = Color('neutral', 255*np.array([0.4824, 0.5216, 0.502]))
 colors.neutral_tint = colors.neutral.tint(50)
 colors.neutral_shade = colors.neutral.shade(50)
+colors.neutral_dark = colors.neutral.shade(75)
 
 # CABBI
 colors.CABBI_blue_light = Color('CABBI_blue_light', '#b2e0e5')
@@ -81,3 +83,18 @@ colors.CABBI_orange = Color('CABBI_orange', '#fcb813')
 colors.CABBI_grey = Color('CABBI_grey', '#e1deda')
 colors.CABBI_brown = Color('CABBI_brown', '#98876e')
 colors.CABBI_black = Color('CABBI_black', '#403a48')
+
+CABBI_palette = Palette(
+    blue_light = colors.CABBI_blue_light,
+    blue = colors.CABBI_blue,
+    teal = colors.CABBI_teal,
+    teal_green = colors.CABBI_teal_green,
+    green_soft = colors.CABBI_green_soft,
+    green_dirty = colors.CABBI_green_dirty,
+    green = colors.CABBI_green,
+    yellow = colors.CABBI_yellow,
+    orange = colors.CABBI_orange,
+    grey = colors.CABBI_grey,
+    brown = colors.CABBI_brown,
+    black = colors.CABBI_black,
+)
